==> sd-shared-web-db-postgres-1.0.7-sources.jar: systems/dennis/shared/postgres/controller/DeleteItemController.java <==
package systems.dennis.shared.postgres.controller;

import org.springframework.web.bind.annotation.*;
import systems.dennis.shared.annotations.security.Id;
import systems.dennis.shared.annotations.security.Secured;
import systems.dennis.shared.annotations.security.WithRole;
import systems.dennis.shared.controller.items.AbstractDeleteItemController;
import systems.dennis.shared.postgres.model.BaseEntity;
import systems.dennis.shared.exceptions.ItemForAddContainsIdException;
import systems.dennis.shared.exceptions.ItemNotFoundException;
import systems.dennis.shared.exceptions.ItemNotUserException;
import systems.dennis.shared.utils.security.DefaultIdChecker;

import java.util.List;

@RestController
@Secured
public interface DeleteItemController<T extends BaseEntity> extends AbstractDeleteItemController<T,Long> {


    @DeleteMapping(value = "/delete/{id}",  consumes = {"application/json", "application/json;charset=UTF-8"}, produces = {"application/json", "application/json;charset=UTF-8"})
    @ResponseBody
    @WithRole
    @Override
    default void delete(@Id(checker = DefaultIdChecker.class) @PathVariable Long id) throws ItemForAddContainsIdException {
        AbstractDeleteItemController.super.delete(id);
    }

    @Override
    @WithRole
    @RequestMapping(value="/delete/deleteItems", method= RequestMethod.POST)
    default void deleteItems(@RequestParam List<Long> ids) throws ItemNotUserException, ItemNotFoundException {
        AbstractDeleteItemController.super.deleteItems(ids);
    }
}

==> sd-shared-web-db-postgres-1.1.2-sources.jar: systems/dennis/shared/postgres/controller/DeleteItemController.java <==
package systems.dennis.shared.postgres.controller;

import org.springframework.web.bind.annotation.*;
import systems.dennis.shared.annotations.security.Id;
import systems.dennis.shared.annotations.security.Secured;
import systems.dennis.shared.annotations.security.WithRole;
import systems.dennis.shared.controller.items.AbstractDeleteItemController;
import systems.dennis.shared.postgres.model.BaseEntity;
import systems.dennis.shared.exceptions.ItemForAddContainsIdException;
import systems.dennis.shared.exceptions.ItemNotFoundException;
import systems.dennis.shared.exceptions.ItemNotUserException;
import systems.dennis.shared.utils.security.DefaultIdChecker;

import java.util.List;

@RestController
@Secured
public interface DeleteItemController<T extends BaseEntity> extends AbstractDeleteItemController<T,Long> {


    @DeleteMapping(value = "/delete/{id}",  consumes = {"application/json", "application/json;charset=UTF-8"}, produces = {"application/json", "application/json;charset=UTF-8"})
    @ResponseBody
    @WithRole
    @Override
    default void delete(@Id(checker = DefaultIdChecker.class) @PathVariable Long id) throws ItemForAddContainsIdException {
        AbstractDeleteItemController.super.delete(id);
    }

    @Override
    @WithRole
    @RequestMapping(value="/delete/deleteItems", method= RequestMethod.DELETE)
    default void deleteItems(@RequestParam List<Long> ids) throws ItemNotUserException, ItemNotFoundException {
        AbstractDeleteItemController.super.deleteItems(ids);
    }
}
